@@ -170,7 +170,8 @@ int assoc_insert(item *it, const uint32_t hv) {
 
     pthread_mutex_lock(&hash_items_counter_lock);
     hash_items++;
-    if (! expanding && hash_items > (hashsize(hashpower) * 3) / 2) {
+    if (! expanding && hash_items > (hashsize(hashpower) * 3) / 2 &&
+          hashpower < HASHPOWER_MAX) {
         assoc_start_expand();
     }
     pthread_mutex_unlock(&hash_items_counter_lock);
@@ -216,7 +217,7 @@ static void *assoc_maintenance_thread(void *arg) {
         /* There is only one expansion thread, so no need to global lock. */
         for (ii = 0; ii < hash_bulk_move && expanding; ++ii) {
             item *it, *next;
-            int bucket;
+            unsigned int bucket;
             void *item_lock = NULL;
 
             /* bucket = hv & hashmask(hashpower) =>the bucket of hash table
